@@ -22,28 +22,32 @@ class  TestHelperMethods(MockTestCase):
         self.site = self.mocker.mock(count=False)
         self.plone_utils = self.mocker.mock(count=False)
         # Mock simple normalizeString Method
-        self.expect(self.plone_utils.normalizeString(ANY)).call(lambda x: x.lower())
+        self.expect(
+            self.plone_utils.normalizeString(ANY)).call(lambda x: x.lower())
         setSite(self.site)
-        self.expect(getToolByName(getSite(), 'plone_utils')).result(self.plone_utils)
+        self.expect(getToolByName(getSite(),
+                    'plone_utils')).result(self.plone_utils)
 
         # Moke portal_properties
         self.prop_tool = self.mocker.mock(count=False)
         self.expect(self.prop_tool.get('site_properties').getProperty(
             'typesUseViewActionInListings')).result([])
-        self.expect(getToolByName(getSite(), 'portal_properties')).result(self.prop_tool)
+        self.expect(getToolByName(getSite(),
+                    'portal_properties')).result(self.prop_tool)
 
 
         # portal_url
-        self.expect(self.item.portal_url()).result('/path/to/portal')
+        self.expect(getToolByName(getSite(),
+                    'portal_url')()).result('/path/to/portal')
 
         # User
         user_mock = self.mocker.mock(count=False)
         self.userid = 'Demo User Name'
         self.expect(user_mock.getProperty('fullname', ANY)).call(
             lambda x, y: self.userid)
-        self.expect(self.item.acl_users.getUserById('demouserid')).result(
+        self.expect(getSite().acl_users.getUserById('demouserid')).result(
             user_mock)
-        self.expect(self.item.acl_users.getUserById('notexisting')).result(
+        self.expect(getSite().acl_users.getUserById('notexisting')).result(
             user_mock)
 
         self.replay()
@@ -250,7 +254,7 @@ class  TestHelperMethods(MockTestCase):
             u'sortAscText')
         self.assertEqual(
             translated_string('ftw.table')(self.item, None),
-            None)
+            'None')
         self.assertEqual(
             translated_string('ftw.table')(self.item, 'sortAscText'),
             u'sortAscText')
